==> zio-aws-amplifyuibuilder_2.12-5.17.104.12-sources.jar: zio/aws/amplifyuibuilder/model/RefreshTokenResponse.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.{
  Integer,
  SyntheticRefreshTokenResponseString
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RefreshTokenResponse(
    accessToken: SyntheticRefreshTokenResponseString,
    expiresIn: Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse = {
    import RefreshTokenResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
      .builder()
      .accessToken(
        SyntheticRefreshTokenResponseString.unwrap(
          accessToken
        ): java.lang.String
      )
      .expiresIn(Integer.unwrap(expiresIn): java.lang.Integer)
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly =
    zio.aws.amplifyuibuilder.model.RefreshTokenResponse.wrap(buildAwsValue())
}
object RefreshTokenResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.RefreshTokenResponse =
      zio.aws.amplifyuibuilder.model
        .RefreshTokenResponse(accessToken, expiresIn)
    def accessToken: SyntheticRefreshTokenResponseString
    def expiresIn: Integer
    def getAccessToken: ZIO[Any, Nothing, SyntheticRefreshTokenResponseString] =
      ZIO.succeed(accessToken)
    def getExpiresIn: ZIO[Any, Nothing, Integer] = ZIO.succeed(expiresIn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ) extends zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly {
    override val accessToken: SyntheticRefreshTokenResponseString =
      zio.aws.amplifyuibuilder.model.primitives
        .SyntheticRefreshTokenResponseString(impl.accessToken())
    override val expiresIn: Integer =
      zio.aws.amplifyuibuilder.model.primitives.Integer(impl.expiresIn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ): zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifyuibuilder_2.12-6.20.149.2-sources.jar: zio/aws/amplifyuibuilder/model/RefreshTokenResponse.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.{Integer, SensitiveString}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RefreshTokenResponse(
    accessToken: SensitiveString,
    expiresIn: Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse = {
    import RefreshTokenResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
      .builder()
      .accessToken(SensitiveString.unwrap(accessToken): java.lang.String)
      .expiresIn(expiresIn: java.lang.Integer)
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly =
    zio.aws.amplifyuibuilder.model.RefreshTokenResponse.wrap(buildAwsValue())
}
object RefreshTokenResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.RefreshTokenResponse =
      zio.aws.amplifyuibuilder.model
        .RefreshTokenResponse(accessToken, expiresIn)
    def accessToken: SensitiveString
    def expiresIn: Integer
    def getAccessToken: ZIO[Any, Nothing, SensitiveString] =
      ZIO.succeed(accessToken)
    def getExpiresIn: ZIO[Any, Nothing, Integer] = ZIO.succeed(expiresIn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ) extends zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly {
    override val accessToken: SensitiveString =
      zio.aws.amplifyuibuilder.model.primitives
        .SensitiveString(impl.accessToken())
    override val expiresIn: Integer = impl.expiresIn(): Integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.RefreshTokenResponse
  ): zio.aws.amplifyuibuilder.model.RefreshTokenResponse.ReadOnly = new Wrapper(
    impl
  )
}
